flutter_floating_bottom_bar library

Classes

BottomBar
A floating bar widget that hosts any child widget above scrollable content and automatically hides/shows in response to scroll events.
BottomBarController
Imperative controller for BottomBar.
BottomBarItem
A simple, opinionated nav-item widget for use inside BottomBar.child.
BottomBarItems
A thin row layout helper for BottomBarItems (or any other widgets).
BottomBarLayout
Layout configuration for BottomBar.
BottomBarMotion
Animation configuration for BottomBar show/hide.
BottomBarScope
Provides bar metadata to descendants of BottomBar.body.
BottomBarScrollBehavior
Configuration for how BottomBar reacts to scrolling in its body subtree.
BottomBarThemeData
App-wide defaults for BottomBar.
CupertinoMotion
A collection of spring motions that are commonly used in Cupertino apps.
CurvedMotion
A motion based on a fixed duration and curve.
LinearMotion
A convenience class for a CurvedMotion that uses a linear curve.
MaterialSpringMotion
Material Design 3 spring motion tokens for expressive design system.
Motion
A motion pattern such as spring physics or duration-based curves.
SpringMotion
A motion based on spring physics.

Enums

BottomBarCupertinoMotion
Built-in Cupertino spring presets for BottomBarMotion.cupertino.
BottomBarMotionMode
Animation engine used by BottomBarMotion.
BottomBarTransition
Built-in transition presets for BottomBar.

Typedefs

BackToTopIconBuilder = Widget Function(double width, double height)
Builds the back-to-top icon child.