MaterialSpringMotion class

Material Design 3 spring motion tokens for expressive design system.

This class provides predefined spring motion tokens that follow the Material Design 3 motion guidelines for creating expressive and natural animations. The tokens are organized into two categories:

  • Spatial: For animating position, size, and layout changes
  • Effects: For animating visual properties like opacity and color

Each category has three speed variants: fast, default, and slow.

See also:

Inheritance

Constructors

MaterialSpringMotion.expressiveEffectsDefault({bool snapToEnd = false})
Expressive effects motion token - default variant.
const
MaterialSpringMotion.expressiveEffectsFast({bool snapToEnd = false})
Expressive effects motion token - fast variant.
const
MaterialSpringMotion.expressiveEffectsSlow({bool snapToEnd = false})
Expressive effects motion token - slow variant.
const
MaterialSpringMotion.expressiveSpatialDefault({bool snapToEnd = false})
Expressive spatial motion token - default variant.
const
MaterialSpringMotion.expressiveSpatialFast({bool snapToEnd = false})
Expressive spatial motion token - fast variant.
const
MaterialSpringMotion.expressiveSpatialSlow({bool snapToEnd = false})
Expressive spatial motion token - slow variant.
const
MaterialSpringMotion.standardEffectsDefault({bool snapToEnd = false})
Standard effects motion token - default variant.
const
MaterialSpringMotion.standardEffectsFast({bool snapToEnd = false})
Standard effects motion token - fast variant.
const
MaterialSpringMotion.standardEffectsSlow({bool snapToEnd = false})
Standard effects motion token - slow variant.
const
MaterialSpringMotion.standardSpatialDefault({bool snapToEnd = false})
Standard spatial motion token - default variant.
const
MaterialSpringMotion.standardSpatialFast({bool snapToEnd = false})
Standard spatial motion token - fast variant.
const
MaterialSpringMotion.standardSpatialSlow({bool snapToEnd = false})
Standard spatial motion token - slow variant.
const

Properties

damping → double
The damping factor of the spring motion.
final
description → SpringDescription
The physical description of the spring.
no setteroverride
hashCode → int
Returns a hash code for this object.
no setterinherited
needsSettle → bool
Whether this motion needs to settle.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapToEnd → bool
Whether to snap to the end of the spring.
finalinherited
stiffness → double
The stiffness factor of the spring motion.
final
tolerance → Tolerance
The tolerance for this motion.
finalinherited
unboundedWillSettle → bool
Whether this motion will settle without bounds.
no setterinherited

Methods

copyWith({double? damping, double? stiffness, bool? snapToEnd}) → MaterialSpringMotion
Creates a new SpringMotion with the same properties as this one, but with the specified description and snapToEnd.
override
createSimulation({double start = 0, double end = 1, double velocity = 0}) → Simulation
Creates a simulation for this motion.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns a string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Equality operator for SpringMotion.
inherited