MaterialSpringMotion.standardEffectsSlow constructor

const MaterialSpringMotion.standardEffectsSlow({
  1. bool snapToEnd = false,
})

Standard effects motion token - slow variant.

Used for deliberate visual property animations where a slower, more gentle motion is desired for opacity, color, and other non-spatial effects.

Damping: 1, Stiffness: 800, Mass: 1

Implementation

const MaterialSpringMotion.standardEffectsSlow({
  bool snapToEnd = false,
}) : this._(
        damping: 1,
        stiffness: 800,
        snapToEnd: snapToEnd,
      );