BottomBarItems class

A thin row layout helper for BottomBarItems (or any other widgets).

Arranges children horizontally with spacing as the main-axis alignment. Designed to be passed as BottomBar.child:

BottomBar(
  child: BottomBarItems(
    children: [
      BottomBarItem(icon: Icon(Icons.home), selected: true, onTap: () {}),
      BottomBarItem(icon: Icon(Icons.search), onTap: () {}),
    ],
  ),
  body: ...,
)
Inheritance

Constructors

BottomBarItems({Key? key, required List<Widget> children, MainAxisAlignment spacing = MainAxisAlignment.spaceAround})
Creates a BottomBarItems row.
const

Properties

children List<Widget>
The widgets to display in the row — typically BottomBarItem instances.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing MainAxisAlignment
Main-axis alignment applied to the Row.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited