LinearMotion class
A convenience class for a CurvedMotion that uses a linear curve.
- Inheritance
-
- Object
- Motion
- CurvedMotion
- LinearMotion
Constructors
- LinearMotion(Duration duration)
-
Creates a linear motion with a fixed duration.
const
Properties
- curve → Curve
-
The curve that defines the rate of change of the motion over time.
finalinherited
- duration → Duration
-
The total duration of the motion.
finalinherited
- hashCode → int
-
Returns a hash code for this object.
no setterinherited
- needsSettle → bool
-
Whether this motion needs to settle.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tolerance → Tolerance
-
The tolerance for this motion.
finalinherited
- unboundedWillSettle → bool
-
Whether this motion will settle without bounds.
no setterinherited
Methods
-
copyWith(
{Duration? duration, Curve? curve}) → CurvedMotion -
Creates a new CurvedMotion with the given parameters.
inherited
-
createSimulation(
{double start = 0, double end = 1, double velocity = 0}) → Simulation -
Creates a simulation for this motion.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a string representation of this object.
override
-
withCurve(
Curve curve) → CurvedMotion -
Applies
curveto the current duration.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited