MaterialSpringMotion.expressiveEffectsSlow constructor
const
MaterialSpringMotion.expressiveEffectsSlow({
- bool snapToEnd = false,
Expressive effects motion token - slow variant.
Used for slower, more deliberate expressive visual property animations. Part of the expressive motion system while maintaining characteristics optimized for opacity, color, and other non-spatial effects.
Damping: 1, Stiffness: 800, Mass: 1
Implementation
const MaterialSpringMotion.expressiveEffectsSlow({
bool snapToEnd = false,
}) : this._(
damping: 1,
stiffness: 800,
snapToEnd: snapToEnd,
);