Motion.curved constructor
A motion based on a fixed duration and curve.
CurvedMotion implements a motion that follows a specific Curve over a fixed Duration. This is the most common type of animation in Flutter, similar to what is used with AnimationController.animateTo.
This motion always completes in the specified duration and does not need to settle.
Implementation
const factory Motion.curved(Duration duration, [Curve curve]) = CurvedMotion;